#!/bin/bash

# This helper script will handle deploying elasticsearch cluster and creating an external service to route
# to the DB
set -e

source /scripts/utils.sh
source /scripts/terraform.sh

check_access ${appsNamespace} services
check_access ${appsNamespace} configmaps

terraform_init
export TF_X_CONCISE_DIFF=0
terraform_plan
unset TF_X_CONCISE_DIFF
terraform_apply
terraform_output

if [ ${awsDeployment} == "true" ]; then
  print_header "Checking for the elasticsearch endpoint"

  terraform_get endpoint elasticsearchClusterEndpoint

  arnConfigMapName=${namingPrefix}-arn
  terraform_get arn arnValue
  terraform_get domainId domainId

  cat >/tmp/arn-configmap.yaml <<EOF
apiVersion: v1
kind: ConfigMap
metadata:
  name: ${arnConfigMapName}
data:
  ARN: ${arnValue}
  domainId: ${domainId}
  endpoint: ${elasticsearchClusterEndpoint}
EOF

  endpointConfigMapName=${namingPrefix}-endpoint

  # strip quotes
  domain="${elasticsearchClusterEndpoint%\"}"
  domain="${domain#\"}"

  cat >/tmp/endpoint-configmap.yaml <<EOF
apiVersion: v1
kind: ConfigMap
metadata:
  name: ${endpointConfigMapName}
data:
  endpoint: ${elasticsearchClusterEndpoint}
  endpointUrlsJson: |
    {"${env}":["https://${domain}:443"]}
EOF

  run_cmd cat "/tmp/arn-configmap.yaml"
  /scripts/wait-until -t 30 -i 5 true kubectl --namespace ${appsNamespace} apply -f /tmp/arn-configmap.yaml
  /scripts/wait-until -t 30 -i 5 true kubectl --namespace ${infraNamespace} apply -f /tmp/arn-configmap.yaml

  echo "Config map ${arnConfigMapName}"
  /scripts/wait-until -t 30 -i 5 true kubectl --namespace ${appsNamespace} get cm ${arnConfigMapName} -o yaml

  run_cmd cat "/tmp/endpoint-configmap.yaml"
  /scripts/wait-until -t 30 -i 5 true kubectl --namespace ${appsNamespace} apply -f /tmp/endpoint-configmap.yaml
  /scripts/wait-until -t 30 -i 5 true kubectl --namespace ${infraNamespace} apply -f /tmp/endpoint-configmap.yaml

  echo "Config map ${endpointConfigMapName}"
  /scripts/wait-until -t 30 -i 5 true kubectl --namespace ${appsNamespace} get cm ${endpointConfigMapName} -o yaml

  # Deprecated - will be removed in 1.0 release
  create_external_service ${dbServiceClusterEndpointShortName} ${appsNamespace} ${elasticsearchClusterEndpoint}
fi

cprint "$0 done"
