#!/bin/bash

# This helper script will handle generation of a secret in the app namespace
#
# /scripts/gen-user-secret.sh
#

set -e

source /scripts/utils.sh

check_access ${infraNamespace} secrets
check_access ${appsNamespace} secrets

## namingPrefix comes from mounted env variables
source /scripts/chartFunctions.sh
## masterUserName could be supplied via Helm, but we'll use
##  the shell function as a fall-back.
user=${esClusterMasterUserName:-$(trimUser $namingPrefix)}
## unlike gen-primary-secret.sh, this one only checks if the password pre-exists before starting it's workflow.

cprint "Checking for secret.."
if /scripts/wait-until -t 30 -i 5 true kubectl --namespace "${appsNamespace}" get secret "${dbUserCredsSecretPassName}"; then
  cprint "Secret ${dbUserCredsSecretPassName} already exists."
else
  echo "No secret found.. Generating new account."
  password=$(openssl rand -base64 24)
  password+="_3"
  if [ ${awsDeployment} == "true" ]; then
    echo "Setting the token for elasticache."
    run_cmd aws es update-elasticsearch-domain-config \
    --region ${awsDefaultRegion} \
    --domain-name ${clusterDomainName} \
    --advanced-security-options MasterUserOptions=\"\{MasterUserName=${user},MasterUserPassword=${password}\}\"
  fi
  echo "Creating kubernetes secret ${dbUserCredsSecretUserName}"
  kubectl --namespace "${appsNamespace}" delete secret "${dbUserCredsSecretUserName}" --ignore-not-found
  kubectl --namespace "${appsNamespace}" create secret generic "${dbUserCredsSecretUserName}" --from-literal=user="${user}"
  echo "Creating kubernetes secret ${dbUserCredsSecretPassName}"
  kubectl --namespace "${appsNamespace}" delete secret "${dbUserCredsSecretPassName}" --ignore-not-found
  kubectl --namespace "${appsNamespace}" create secret generic "${dbUserCredsSecretPassName}" --from-literal=password="${password}"
  echo "Syncing seed token with new account"
  kubectl --namespace "${infraNamespace}" delete secret "${dbUserCredsSecretPassName}" --ignore-not-found
  kubectl --namespace "${infraNamespace}" delete secret "${dbUserCredsSecretUserName}" --ignore-not-found
  kubectl --namespace "${infraNamespace}" create secret generic "${dbUserCredsSecretPassName}" --from-literal=password="${password}"
  kubectl --namespace "${infraNamespace}" create secret generic "${dbUserCredsSecretUserName}" --from-literal=user="${user}"
fi

print_header "$0 done."
