variable "aws_arn_prefix" {
  type        = string
  description = "Arn Prefix for AWS resources. Gov: arn:aws-us-gov, Com: arn:aws"
}

variable "cluster_domain_name" {
  type = string
}

variable "es_cluster_automated_snapshot_start_hour" {
  type = number
}

variable "es_cluster_dedicated_master_count" {
  type = number
}

variable "es_cluster_dedicated_master_enabled" {
  type = string
}

variable "es_cluster_dedicated_master_type" {
  type = string
}

variable "es_cluster_ebs_iops" {
  type = number
}

variable "es_cluster_ebs_volume_size" {
  type = number
}

variable "es_cluster_ebs_volume_type" {
  type = string
}

variable "es_cluster_instance_count" {
  type = number
}

variable "es_cluster_instance_type" {
  type = string
}

variable "es_cluster_master_user_name" {
  type = string
}

variable "es_cluster_master_user_password" {
  type = string
}

variable "es_cluster_warm_count" {
  type    = number
  default = null
}

variable "es_cluster_warm_enabled" {
  type = string
}

variable "es_cluster_warm_type" {
  type    = string
  default = null
}

variable "es_version" {
  type = string
}

## one for each: INDEX_SLOW_LOGS, SEARCH_SLOW_LOGS, ES_APPLICATION_LOGS, AUDIT_LOGS

variable "log_retention_index_slow_logs" {
  description = <<-EOT
  Specifies the number of days you want to retain INDEX_SLOW_LOGS log events.
  Possible values are: 1, 3, 5, 7, 14, 30, 60, 90, 120, 150, 180, 365, 400, 545, 731, 1827, 3653, and 0.
  If you select 0, the events in the log group are always retained and never expire.
  EOT
  type        = number
  default     = null

  validation {
    condition = (
      var.log_retention_index_slow_logs == null ||
      contains([1, 3, 5, 7, 14, 30, 60, 90, 120, 150, 180, 365, 400, 545, 731, 1827, 3653, 0], coalesce(var.log_retention_index_slow_logs, 2))
    )

    error_message = "Valid log retention values: 1,3,5,7,14,30,60,90,120,150,180,365,400,545,731,1827,3653,0."
  }
}

variable "log_retention_search_slow_logs" {
  description = <<-EOT
  Specifies the number of days you want to retain SEARCH_SLOW_LOGS log events.
  Possible values are: 1, 3, 5, 7, 14, 30, 60, 90, 120, 150, 180, 365, 400, 545, 731, 1827, 3653, and 0.
  If you select 0, the events in the log group are always retained and never expire.
  EOT
  type        = number
  default     = null

  validation {
    condition = (
      var.log_retention_search_slow_logs == null ||
      contains([1, 3, 5, 7, 14, 30, 60, 90, 120, 150, 180, 365, 400, 545, 731, 1827, 3653, 0], coalesce(var.log_retention_search_slow_logs, 2))
    )

    error_message = "Valid log retention values: 1,3,5,7,14,30,60,90,120,150,180,365,400,545,731,1827,3653,0."
  }
}

variable "log_retention_es_application_logs" {
  description = <<-EOT
  Specifies the number of days you want to retain ES_APPLICATION_LOGS log events.
  Possible values are: 1, 3, 5, 7, 14, 30, 60, 90, 120, 150, 180, 365, 400, 545, 731, 1827, 3653, and 0.
  If you select 0, the events in the log group are always retained and never expire.
  EOT
  type        = number
  default     = null

  validation {
    condition = (
      var.log_retention_es_application_logs == null ||
      contains([1, 3, 5, 7, 14, 30, 60, 90, 120, 150, 180, 365, 400, 545, 731, 1827, 3653, 0], coalesce(var.log_retention_es_application_logs, 2))
    )

    error_message = "Valid log retention values: 1,3,5,7,14,30,60,90,120,150,180,365,400,545,731,1827,3653,0."
  }
}

variable "log_retention_audit_logs" {
  description = <<-EOT
  Specifies the number of days you want to retain AUDIT_LOGS log events.
  Possible values are: 1, 3, 5, 7, 14, 30, 60, 90, 120, 150, 180, 365, 400, 545, 731, 1827, 3653, and 0.
  If you select 0, the events in the log group are always retained and never expire.
  EOT
  type        = number
  default     = null

  validation {
    condition = (
      var.log_retention_audit_logs == null ||
      contains([1, 3, 5, 7, 14, 30, 60, 90, 120, 150, 180, 365, 400, 545, 731, 1827, 3653, 0], coalesce(var.log_retention_audit_logs, 2))
    )

    error_message = "Valid log retention values: 1,3,5,7,14,30,60,90,120,150,180,365,400,545,731,1827,3653,0."
  }
}

variable "read_only_roles" {
  type    = list(string)
  default = []
}

variable "read_write_roles" {
  type    = list(string)
  default = []
}

variable "security_group_ids" {
  type = list(string)
  ## sic: these are provided by the env_definitions file
  default = []
}

variable "subnet_ids" {
  type = list(string)
  ## sic: these are provided by the env_definitions file
  default = []
}

variable "tags" {
  description = "Tags for Elasticsearch"
  type        = map(string)
}

variable "vpc_id" {
  type = string
}

## Advanced Options ##
## -------------------

variable "indices_query_bool_max_clause_count" {
  description = "Max number of bool clause"
  type        = number
  default     = 1024
}
